<?php
class PressPayShortcodeController {
  public function __construct() {
    add_shortcode( 'presspay', array($this, 'route') );
 }

  public function route( $shortcode_attributes, $content = null ) {
    DebugModel::debug( 'route()' );

    switch ( $_SERVER['REQUEST_METHOD'] ) {
      case 'GET':
        return( $this->get( $shortcode_attributes ) );
      case 'POST':
        return( $this->post() );
      default:
        die( "{$_SERVER['REQUEST_METHOD']} not supported by PressPay" );
    }
  }

  // maps to new in rails - new is a keyword in php :(
  public function get( $shortcode_attributes ) {
    DebugModel::debug( 'PressPayShortcodesController::get' );

    extract( shortcode_atts( array(
      'amount'      => '',
      'image'       => '',
      'headline'    => get_bloginfo( 'title' ),
      'product_id'  => '',
      'description' => get_bloginfo( 'description' )
    ), $shortcode_attributes ) );

    $redirect        = get_permalink();
    $base64_amount   = base64_encode( $amount );
    $stripe_nonce    = wp_create_nonce('stripe-nonce');
    $publishable_key = PressPaySettings::get_stripe_publishable_key();

    // abstract into render() method in base class.
    ob_start();
    include( STRIPE_BASE_DIR . '/app/view/shortcode/stripe_button_form.php' );
    return ob_get_clean();
  }

  // maps to create in rails
  public function post() {
    DebugModel::debug( 'PressPayShortcodesController::post()' );
    if (wp_verify_nonce($_POST['stripe_nonce'], 'stripe-nonce')) {
      try {
        Stripe::setApiKey( PressPaySettings::get_stripe_secret_key() );

        // create a stripe customer
        $stripe_client = Stripe_Customer::create( array( 'card' => $_POST['stripeToken'] ) );

        // charge the stripe customer
        $amount = base64_decode( $_POST['amount'] );
        $charge = Stripe_Charge::create(
          array(
            'amount'   => $amount,
            'currency' => 'usd',
            'customer' => $stripe_client->id,
          )
        );

        // create a presspay customer
        $customer = new PressPayCustomer( array(
          'stripe_client_id'         => $stripe_client->id,
          'wp_user_id'               => null,
          'email'                    => $_POST['stripeEmail'],
          'billing_name'             => $_POST['stripeBillingName'],
          'billing_address_line_1'   => $_POST['stripeBillingAddressLine1'],
          'billing_address_zip'      => $_POST['stripeBillingAddressZip'],
          'billing_address_city'     => $_POST['stripeBillingAddressCity'],
          'billing_address_state'    => $_POST['stripeBillingAddressState'],
          'billing_address_country'  => $_POST['stripeBillingAddressCountry'],
          'shipping_name'            => $_POST['stripeShippingName'],
          'shipping_address_line_1'  => $_POST['stripeShippingAddressLine1'],
          'shipping_address_zip'     => $_POST['stripeShippingAddressZip'],
          'shipping_address_city'    => $_POST['stripeShippingAddressCity'],
          'shipping_address_state'   => $_POST['stripeShippingAddressState'],
          'shipping_address_country' => $_POST['stripeShippingAddressCountry']
        ));
        $customer->save();

        // create a presspay transaction
        $transaction = new PressPayTransaction( array(
          'press_pay_customer_id' => $customer->id,
          'amount'                => $amount,
          'type'                  => 'charge.initiated'
        ));
        $transaction->save();

        // send the emails
        $email = new EmailController();
        $email->send_emails($customer, $transaction, $_POST['product_id'], $_POST['description'] );
      }
      catch (Exception $e) {
        wp_die($e);
      }

      // abstract into render() method in base class.
      ob_start();
      include( STRIPE_BASE_DIR . '/app/view/shortcode/thank_you.php' );
      return ob_get_clean();
    }
  }
}
?>
